@@ -13,13 +13,12 @@ package Device::I2C;
 # This is free software; you can redistribute it and/or modify it under
 # the same terms as the Perl 5 programming language system itself.
 #
-our $VERSION = '0.03'; # VERSION
+our $VERSION = '0.04'; # VERSION
 
-our (@ISA);
-@ISA = qw(IO::Handle);
+our @ISA = qw(IO::Handle);
 
 # Dependencies
-use 5.010000;
+use v5.10.1;
 
 use Carp;
 use IO::File;
@@ -52,15 +51,10 @@ sub fileError {
 }
 
 
-sub check {
+sub checkDevice {
     my ( $fh, $addr ) = @_;
-    if ( $fh->ioctl( I2C_SLAVE, $addr ) < 0 ) {
-        printf( "Device 0x%x not found\n", $addr );
-        return 1;
-    }
-    else {
-        return 0;
-    }
+    my $retval = Device::I2C::_check_device( $fh->fileno(), $addr );
+    return $retval;
 }
 
 
@@ -187,8 +181,8 @@ Device::I2C - Control and read hardware devices with i2c(SMBus)
 <p>
 <img src="https://img.shields.io/badge/perl-5.10+-brightgreen.svg" alt="Requires Perl 5.10+" />
 <a href="https://travis-ci.org/shantanubhadoria/perl-Device-I2C"><img src="https://api.travis-ci.org/shantanubhadoria/perl-Device-I2C.svg?branch=build/master" alt="Travis status" /></a>
-<a href="http://matrix.cpantesters.org/?dist=Device-I2C%200.03"><img src="https://badgedepot.code301.com/badge/cpantesters/Device-I2C/0.03" alt="CPAN Testers result" /></a>
-<a href="http://cpants.cpanauthors.org/dist/Device-I2C-0.03"><img src="https://badgedepot.code301.com/badge/kwalitee/Device-I2C/0.03" alt="Distribution kwalitee" /></a>
+<a href="http://matrix.cpantesters.org/?dist=Device-I2C%200.04"><img src="https://badgedepot.code301.com/badge/cpantesters/Device-I2C/0.04" alt="CPAN Testers result" /></a>
+<a href="http://cpants.cpanauthors.org/dist/Device-I2C-0.04"><img src="https://badgedepot.code301.com/badge/kwalitee/Device-I2C/0.04" alt="Distribution kwalitee" /></a>
 <a href="https://gratipay.com/shantanubhadoria"><img src="https://img.shields.io/gratipay/shantanubhadoria.svg" alt="Gratipay" /></a>
 </p>
 
@@ -196,7 +190,7 @@ Device::I2C - Control and read hardware devices with i2c(SMBus)
 
 =head1 VERSION
 
-version 0.03
+version 0.04
 
 =head1 SYNOPSIS
 
@@ -266,9 +260,9 @@ you should now see the addresses of the i2c devices connected to your i2c bus
 
 returns IO::Handle->error() for the device handle since the last clearerr
 
-=head2 check
+=head2 checkDevice
 
- $self->check($register_address)
+ $self->checkDevice($register_address)
 
 Check device
 
@@ -429,7 +423,7 @@ L<Fcntl>
 =head2 Bugs / Feature Requests
 
 Please report any bugs or feature requests through github at 
-L<https://github.com/shantanubhadoria/perl-device-i2c/issues>.
+L<https://github.com/sv99/perl-device-i2c/issues>.
 You will be notified automatically of any progress on your issue.
 
 =head2 Source Code
@@ -437,9 +431,9 @@ You will be notified automatically of any progress on your issue.
 This is open source software.  The code repository is available for
 public review and contribution under the terms of the license.
 
-L<https://github.com/shantanubhadoria/perl-device-i2c>
+L<https://github.com/sv99/perl-device-i2c>
 
-  git clone git://github.com/shantanubhadoria/perl-device-i2c.git
+  git clone git://github.com/sv99/perl-device-i2c.git
 
 =head1 AUTHOR
 
